summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/accumulator_std_dev.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/pipeline/accumulator_std_dev.cpp')
-rw-r--r--src/mongo/db/pipeline/accumulator_std_dev.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/pipeline/accumulator_std_dev.cpp b/src/mongo/db/pipeline/accumulator_std_dev.cpp
index 55367d766be..cdd31b2c897 100644
--- a/src/mongo/db/pipeline/accumulator_std_dev.cpp
+++ b/src/mongo/db/pipeline/accumulator_std_dev.cpp
@@ -96,20 +96,20 @@ Value AccumulatorStdDev::getValue(bool toBeMerged) {
}
}
-intrusive_ptr<Accumulator> AccumulatorStdDevSamp::create(
+intrusive_ptr<AccumulatorState> AccumulatorStdDevSamp::create(
const boost::intrusive_ptr<ExpressionContext>& expCtx) {
return new AccumulatorStdDevSamp(expCtx);
}
-intrusive_ptr<Accumulator> AccumulatorStdDevPop::create(
+intrusive_ptr<AccumulatorState> AccumulatorStdDevPop::create(
const boost::intrusive_ptr<ExpressionContext>& expCtx) {
return new AccumulatorStdDevPop(expCtx);
}
AccumulatorStdDev::AccumulatorStdDev(const boost::intrusive_ptr<ExpressionContext>& expCtx,
bool isSamp)
- : Accumulator(expCtx), _isSamp(isSamp), _count(0), _mean(0), _m2(0) {
- // This is a fixed size Accumulator so we never need to update this
+ : AccumulatorState(expCtx), _isSamp(isSamp), _count(0), _mean(0), _m2(0) {
+ // This is a fixed size AccumulatorState so we never need to update this
_memUsageBytes = sizeof(*this);
}